@@ -439,7 +439,8 @@ def test_trim_adapters_single_end():
         with gzip.open(truth_path) as truth, gzip.open(out_path) as out:
             assert truth.read() == out.read()
     finally:
-        Path(out_path).unlink()
+        if Path(out_path).exists():
+            Path(out_path).unlink()
         for file in Path(out_dir).iterdir():
             if file.is_file() and file.suffix == '.log':
                 file.unlink()
@@ -463,9 +464,9 @@ def test_trim_adapters_paired_end():
         with gzip.open(truth2_path) as truth, gzip.open(out2_path) as out:
             assert truth.read() == out.read()
     finally:
-
-        Path(out1_path).unlink()
-        Path(out2_path).unlink()
+        for pth in [out1_path, out2_path]:
+            if Path(pth).exists():
+                Path(pth).unlink()
         for file in Path(out_dir).iterdir():
             if file.is_file() and file.suffix == '.log':
                 file.unlink()
@@ -506,6 +507,7 @@ def test_trim_adapters_single_end_command(monkeypatch, fastq_folder, output_fold
         assert print_stderr
 
     monkeypatch.setattr(io, 'run_subprocess', mock_run_subprocess)
+    monkeypatch.setattr(io,'generate_base_call',lambda *args, **kwargs: ['cutadapt'])
 
     trim_adapters_single_end(fastq_folder, output_folder, three_prime_adapters,
                              five_prime_adapters, any_position_adapters, quality_trimming, trim_n,
@@ -559,6 +561,7 @@ def test_trim_adapters_paired_end_command(monkeypatch, fastq_1, fastq_2, output_
         assert print_stderr
 
     monkeypatch.setattr(io, 'run_subprocess', mock_run_subprocess)
+    monkeypatch.setattr(io,'generate_base_call',lambda *args, **kwargs: ['cutadapt'])
 
     trim_adapters_paired_end(fastq_1, fastq_2, output_folder, three_prime_r1, three_prime_r2,
                              five_prime_r1, five_prime_r2, any_position_r1, any_position_r2,
