@@ -3,6 +3,7 @@ import joblib
 from rnalysis.gui.gui_widgets import *
 import time
 from typing_extensions import Literal
+from typing import Set
 from rnalysis.utils import io
 
 LEFT_CLICK = QtCore.Qt.LeftButton
@@ -30,145 +31,6 @@ def test_StrIntLineEdit(qtbot, item, expected):
     assert widget.text() == expected
 
 
-@pytest.mark.parametrize("item,expected", [
-    ('hello', 'hello'),
-    ('57', '57'),
-    ('', '')
-])
-def test_OptionalLineEdit(qtbot, item, expected):
-    qtbot, widget = widget_setup(qtbot, OptionalLineEdit)
-    qtbot.keyClicks(widget.line, item)
-
-    assert widget.line.isEnabled()
-    assert widget.text() == item
-
-    qtbot.mouseClick(widget.checkbox, LEFT_CLICK)
-
-    assert widget.text() is None
-    assert not widget.line.isEnabled()
-
-    qtbot.mouseClick(widget.checkbox, LEFT_CLICK)
-
-    assert widget.line.isEnabled()
-    assert widget.text() == item
-
-
-@pytest.mark.parametrize("item,expected", [
-    ('hello', 'hello'),
-    (None, None),
-    ('57', '57'),
-    ('', '')
-])
-def test_OptionalLineEdit_setText(qtbot, item, expected):
-    qtbot, widget = widget_setup(qtbot, OptionalLineEdit)
-    widget.setText(item)
-    assert widget.text() == expected
-
-    if item is None:
-        assert not widget.line.isEnabled()
-    else:
-        assert widget.line.isEnabled()
-
-
-@pytest.mark.parametrize("item,expected", [
-    ('57', 57),
-    ('-32', -32),
-    ('0', 0),
-])
-def test_OptionalSpinBox(qtbot, item, expected):
-    qtbot, widget = widget_setup(qtbot, OptionalSpinBox)
-    widget.setMinimum(-100)
-    widget.setMaximum(100)
-    widget.spinbox.clear()
-    qtbot.keyClicks(widget.spinbox, item)
-
-    path = qtbot.screenshot(widget)
-    assert widget.spinbox.isEnabled()
-    assert widget.value() == expected
-
-    qtbot.mouseClick(widget.checkbox, LEFT_CLICK)
-
-    assert widget.value() is None
-    assert not widget.spinbox.isEnabled()
-
-    qtbot.mouseClick(widget.checkbox, LEFT_CLICK)
-
-    assert widget.spinbox.isEnabled()
-    assert widget.value() == expected
-
-
-@pytest.mark.parametrize("item,expected", [
-    (57, 57),
-    (-32, -32),
-    (0, 0),
-    (None, None)
-])
-def test_OptionalSpinBox_setValue(qtbot, item, expected):
-    qtbot, widget = widget_setup(qtbot, OptionalSpinBox)
-    widget.setMinimum(-100)
-    widget.setMaximum(100)
-
-    widget.setValue(item)
-    assert widget.value() == expected
-
-    if item is None:
-        assert not widget.spinbox.isEnabled()
-    else:
-        assert widget.spinbox.isEnabled()
-
-
-@pytest.mark.parametrize("item,expected", [
-    ('57', 57),
-    ('-32', -32),
-    ('0', 0),
-    ('3.14', 3.14),
-    ('-0.75', -0.75)
-])
-def test_OptionalDoubleSpinBox(qtbot, item, expected):
-    qtbot, widget = widget_setup(qtbot, OptionalDoubleSpinBox)
-    widget.setMinimum(-100)
-    widget.setMaximum(100)
-    widget.setSingleStep(0.01)
-    widget.spinbox.clear()
-    qtbot.keyClicks(widget.spinbox, item)
-
-    path = qtbot.screenshot(widget)
-    assert widget.spinbox.isEnabled()
-    assert widget.value() == expected
-
-    qtbot.mouseClick(widget.checkbox, LEFT_CLICK)
-
-    assert widget.value() is None
-    assert not widget.spinbox.isEnabled()
-
-    qtbot.mouseClick(widget.checkbox, LEFT_CLICK)
-
-    assert widget.spinbox.isEnabled()
-    assert widget.value() == expected
-
-
-@pytest.mark.parametrize("item,expected", [
-    (57, 57),
-    (-32, -32),
-    (0, 0),
-    (3.14, 3.14),
-    (-0.75, -0.75),
-    (None, None)
-])
-def test_OptionalDoubleSpinBox_setValue(qtbot, item, expected):
-    qtbot, widget = widget_setup(qtbot, OptionalDoubleSpinBox)
-    widget.setMinimum(-100)
-    widget.setMaximum(100)
-
-    widget.setValue(item)
-    assert widget.value() == expected
-
-    if item is None:
-        assert not widget.spinbox.isEnabled()
-    else:
-        assert widget.spinbox.isEnabled()
-
-
 @pytest.mark.parametrize("item,expected", [
     ('black', '#000000'),
     ('#123456', '#123456'),
@@ -291,11 +153,10 @@ def test_get_val_from_widget_native_types(qtbot, widget_class, keyboard_interact
 
 
 @pytest.mark.parametrize("widget_class,keyboard_interact,attr,expected_val,kwargs", [
-    (OptionalSpinBox, True, 'spinbox', 12, {}),
-    (OptionalDoubleSpinBox, True, 'spinbox', 12, {}),
     (PathLineEdit, True, 'file_path', '12', {}),
     (StrIntLineEdit, True, None, 12, {}),
-    (OptionalLineEdit, True, 'line', '12', {}),
+    (OptionalWidget, False, 'checkbox', None, {}),
+    (OptionalWidget, False, 'other', True, {}),
     (ComboBoxOrOtherWidget, True, 'combo', '12',
      {'items': ['opt1', 'opt2', '12'], 'default': 'opt1'}),
     (ComboBoxOrOtherWidget, True, 'other', '12',
@@ -306,6 +167,9 @@ def test_get_val_from_widget_nonnative_types(qtbot, widget_class, keyboard_inter
     if widget_class == ComboBoxOrOtherWidget:
         kwargs['other'] = QtWidgets.QLineEdit()
         kwargs['other'].setText('12')
+    elif widget_class == OptionalWidget:
+        kwargs['other'] = ToggleSwitch()
+        kwargs['other'].setChecked(True)
     qtbot, widget = widget_setup(qtbot, widget_class, **kwargs)
     interact_with = widget if attr is None else getattr(widget, attr)
     if keyboard_interact:
@@ -321,7 +185,7 @@ def test_get_val_from_widget_nonnative_types(qtbot, widget_class, keyboard_inter
     (QMultiDoubleSpinBox, [0.1, 3.2, 5], 0.0, [0.1, 3.2, 5], {}),
     (QMultiLineEdit, ['', 'text', 'other text'], [], ['', 'text', 'other text'], {}),
     (QMultiStrIntLineEdit, ['3', '-7', 'text', 'othertext', 'param5'], [], [3, -7, 'text', 'othertext', 'param5'], {}),
-    (QMultiBoolComboBox, [True, True, False, True], True, [True, True, False, True], {}),
+    (QMultiToggleSwitch, [True, True, False, True], False, [True, True, False, True], {}),
     (MultiColorPicker, ['r', 'black', '#0000ff'], None, ['#ff0000', '#000000', '#0000ff'], {}),
     (QMultiComboBox, ['option3', 'option2', 'option2'], 'option1', ['option3', 'option2', 'option2'],
      {'items': ['option1', 'option2', 'option3']}),
@@ -334,11 +198,11 @@ def test_get_val_from_widget_multiinput_types(qtbot, widget_class, default, exce
         qtbot, widget = widget_setup(qtbot, widget_class, label='label', **kwargs)
     assert get_val_from_widget(widget) == excepted_val_empty
 
-    widget.set_defaults(default)
+    widget.setValue(default)
     assert get_val_from_widget(widget) == expected_val
 
 
-@pytest.mark.parametrize("widget_class", (QtWidgets.QWidget, QtWidgets.QDial))
+@pytest.mark.parametrize("widget_class", (QtWidgets.QWidget, QtWidgets.QDateTimeEdit))
 def test_get_val_from_widget_bad_widget(qtbot, widget_class):
     qtbot, widget = widget_setup(qtbot, widget_class)
     with pytest.raises(TypeError):
@@ -391,13 +255,13 @@ def test_ComparisonPicker_init(qtbot):
 
 def test_ComparisonPicker_get_value(qtbot):
     qtbot, widget = widget_setup(qtbot, ComparisonPicker, io.load_csv('tests/test_files/test_design_matrix.csv', 0))
-    assert widget.get_value() == ('condition', 'cond1', 'cond1')
+    assert widget.value() == ('condition', 'cond1', 'cond1')
 
     widget.factor.setCurrentText('replicate')
     widget.numerator.setCurrentText('rep3')
     widget.denominator.setCurrentText('rep2')
 
-    assert widget.get_value() == ('replicate', 'rep3', 'rep2')
+    assert widget.value() == ('replicate', 'rep3', 'rep2')
 
 
 def test_ComparisonPickerGroup_init(qtbot):
@@ -598,7 +462,7 @@ def test_TableColumnPicker_select_all(qtbot):
     qtbot.mouseClick(widget.clear_button, LEFT_CLICK)
     qtbot.mouseClick(widget.select_all_button, LEFT_CLICK)
     qtbot.mouseClick(widget.done_button, LEFT_CLICK)
-    assert widget.get_values() == cols
+    assert widget.value() == cols
     assert len(changed) == 1
 
 
@@ -612,7 +476,7 @@ def test_TableColumnPicker_clear_selection(qtbot):
 
     qtbot.mouseClick(widget.clear_button, LEFT_CLICK)
     qtbot.mouseClick(widget.done_button, LEFT_CLICK)
-    assert widget.get_values() == []
+    assert widget.value() == []
     assert len(changed) == 1
 
 
@@ -630,7 +494,7 @@ def test_TableColumnPicker_custom_selection(qtbot, selections):
         ind = cols.index(selection)
         qtbot.mouseClick(widget.column_checks[ind].switch, LEFT_CLICK)
     qtbot.mouseClick(widget.done_button, LEFT_CLICK)
-    assert widget.get_values() == selections
+    assert widget.value() == selections
     assert len(changed) == 1
 
 
@@ -647,7 +511,7 @@ def test_TableSingleColumnPicker_custom_selection(qtbot, selections):
         ind = cols.index(selection)
         qtbot.mouseClick(widget.column_checks[ind].switch, LEFT_CLICK)
     qtbot.mouseClick(widget.done_button, LEFT_CLICK)
-    assert widget.get_values() == selections[-1]
+    assert widget.value() == selections[-1]
     assert len(changed) == 1
 
 
@@ -663,7 +527,7 @@ def test_TableColumnGroupPicker_select_all(qtbot):
     qtbot.mouseClick(widget.clear_button, LEFT_CLICK)
     qtbot.mouseClick(widget.select_all_button, LEFT_CLICK)
     qtbot.mouseClick(widget.done_button, LEFT_CLICK)
-    assert widget.get_values() == truth
+    assert widget.value() == truth
     assert len(changed) == 1
 
 
@@ -677,7 +541,7 @@ def test_TableColumnGroupPicker_clear_selection(qtbot):
 
     qtbot.mouseClick(widget.clear_button, LEFT_CLICK)
     qtbot.mouseClick(widget.done_button, LEFT_CLICK)
-    assert widget.get_values() == []
+    assert widget.value() == []
     assert len(changed) == 1
 
 
@@ -696,7 +560,7 @@ def test_TableColumnGroupPicker_custom_selection(qtbot, selections):
         ind = cols.index(selection)
         qtbot.mouseClick(widget.column_checks[ind].switch, LEFT_CLICK)
     qtbot.mouseClick(widget.done_button, LEFT_CLICK)
-    assert widget.get_values() == truth
+    assert widget.value() == truth
     assert len(changed) == 1
 
 
@@ -717,12 +581,12 @@ def test_TableColumnGroupPicker_custom_selection_grouped(qtbot, selections):
             qtbot.keyClicks(widget.column_combos[ind], str(i + 1))
 
     qtbot.mouseClick(widget.done_button, LEFT_CLICK)
-    assert widget.get_values() == selections
+    assert widget.value() == selections
     assert len(changed) == 1
 
     widget.reset()
 
-    assert widget.get_values() == [[item] for item in cols]
+    assert widget.value() == [[item] for item in cols]
 
 
 def test_PathInputDialog(qtbot):
@@ -991,19 +855,19 @@ def test_TrueFalseBoth(qtbot):
     selection_changed = []
     qtbot, widget = widget_setup(qtbot, TrueFalseBoth)
     widget.selectionChanged.connect(functools.partial(selection_changed.append, True))
-    assert widget.get_values() == []
+    assert widget.value() == []
     assert selection_changed == []
 
     qtbot.mouseClick(widget.true_button, LEFT_CLICK)
-    assert widget.get_values() == [True]
+    assert widget.value() == [True]
     assert selection_changed == [True]
 
     qtbot.mouseClick(widget.false_button, LEFT_CLICK)
-    assert widget.get_values() == [True, False]
+    assert widget.value() == [True, False]
     assert selection_changed == [True, True]
 
     qtbot.mouseClick(widget.true_button, LEFT_CLICK)
-    assert widget.get_values() == [False]
+    assert widget.value() == [False]
     assert selection_changed == [True, True, True]
 
 
@@ -1082,8 +946,8 @@ def test_RadioButtonBox_emit(qtbot):
     (int, 15, QtWidgets.QSpinBox),
     (float, 3.14, QtWidgets.QDoubleSpinBox),
     (Literal['a1', 'b1', 'c1'], 'b1', QtWidgets.QComboBox),
-    (typing.Union[str, float, None, bool], True, QtWidgets.QTextEdit),
-    (typing.Union[str, float, None, bool], 17, QtWidgets.QTextEdit)
+    (Union[str, float, None, bool], True, OptionalWidget),
+    (Union[str, float, bool], 17, QtWidgets.QTextEdit)
 ])
 def test_param_to_widget_native_types(qtbot, param_type, default, expected_widget):
     _run_param_to_widget(qtbot, param_type, default, 'param_name', expected_widget)
@@ -1091,32 +955,32 @@ def test_param_to_widget_native_types(qtbot, param_type, default, expected_widge
 
 @pytest.mark.parametrize('param_type,default,name,expected_widget', [
     (bool, True, 'status', ToggleSwitch),
-    (str, '#000000', 'linecolor', ColorPicker),
-    (typing.List[str], ['#000000', '#aabbcc'], 'colors', MultiColorPicker),
-    (typing.Union[str, None], None, 'name', OptionalLineEdit),
-    (typing.Union[str, None], 'text', 'name', OptionalLineEdit),
-    (typing.Union[int, None], None, 'name', OptionalSpinBox),
-    (typing.Union[int, None], 5, 'name', OptionalSpinBox),
-    (typing.Union[float, None], None, 'name', OptionalDoubleSpinBox),
-    (typing.Union[float, None], -0.5, 'name', OptionalDoubleSpinBox),
-    (typing.Union[str, typing.List[str]], ['a', 'b'], 'name', QMultiLineEdit),
-    (typing.Union[str, typing.Iterable[str]], None, 'name', QMultiLineEdit),
-    (typing.Union[int, typing.List[int]], [2, 7], 'name', QMultiSpinBox),
-    (typing.Union[int, typing.Iterable[int]], None, 'name', QMultiSpinBox),
-    (typing.Union[float, typing.List[float]], [2.5, -0.72], 'name', QMultiDoubleSpinBox),
-    (typing.Union[float, typing.Iterable[float]], None, 'name', QMultiDoubleSpinBox),
-    (typing.Union[bool, typing.List[bool]], [True, False, True], 'name', QMultiBoolComboBox),
-    (typing.Union[bool, typing.Iterable[bool]], None, 'name', QMultiBoolComboBox),
-    (typing.List[Literal['a', 'b', 'c']], ['a', 'b', 'a'], 'name', QMultiComboBox),
-    (typing.Set[Literal['a', 'b', 'c']], 'c', 'name', QMultiComboBox),
-    (typing.Iterable[Literal['a', 'b', 'c']], None, 'name', QMultiComboBox),
-    (typing.Union[str, int], 5, 'name', StrIntLineEdit),
-    (typing.Union[str, int], 'text', 'name', StrIntLineEdit),
-    (typing.Union[str, Path], str(Path('tests/test_files/test_deseq.csv').absolute()), 'name', PathLineEdit),
-    (typing.Union[bool, typing.Tuple[bool, bool]], True, 'name', TrueFalseBoth),
-    (typing.Union[bool, typing.Tuple[bool, bool]], [True, False], 'name', TrueFalseBoth),
-    (typing.Union[str, int, typing.List[str], typing.List[int]], [3, 5, -2], 'name', QMultiStrIntLineEdit),
-    (typing.Union[str, int, typing.Iterable[str], typing.Iterable[int]], ['a', 'b', 'c'], 'name', QMultiStrIntLineEdit)
+    (param_typing.Color, '#000000', 'linecolor', ColorPicker),
+    (param_typing.ColorList, ['#000000', '#aabbcc'], 'colors', MultiColorPicker),
+    (Union[str, None], None, 'name', OptionalWidget),
+    (Union[str, None], 'text', 'name', OptionalWidget),
+    (Union[int, None], None, 'name', OptionalWidget),
+    (Union[int, None], 5, 'name', OptionalWidget),
+    (Union[float, None], None, 'name', OptionalWidget),
+    (Union[float, None], -0.5, 'name', OptionalWidget),
+    (Union[str, List[str]], ['a', 'b'], 'name', QMultiLineEdit),
+    (Union[str, Iterable[str]], None, 'name', QMultiLineEdit),
+    (Union[int, List[int]], [2, 7], 'name', QMultiSpinBox),
+    (Union[int, Iterable[int]], None, 'name', QMultiSpinBox),
+    (Union[float, List[float]], [2.5, -0.72], 'name', QMultiDoubleSpinBox),
+    (Union[float, Iterable[float]], None, 'name', QMultiDoubleSpinBox),
+    (Union[bool, List[bool]], [True, False, True], 'name', QMultiToggleSwitch),
+    (Union[bool, Iterable[bool]], None, 'name', QMultiToggleSwitch),
+    (List[Literal['a', 'b', 'c']], ['a', 'b', 'a'], 'name', QMultiComboBox),
+    (Set[Literal['a', 'b', 'c']], 'c', 'name', QMultiComboBox),
+    (Iterable[Literal['a', 'b', 'c']], None, 'name', QMultiComboBox),
+    (Union[str, int], 5, 'name', StrIntLineEdit),
+    (Union[str, int], 'text', 'name', StrIntLineEdit),
+    (Union[str, Path], str(Path('tests/test_files/test_deseq.csv').absolute()), 'name', PathLineEdit),
+    (Union[bool, Tuple[bool, bool]], True, 'name', TrueFalseBoth),
+    (Union[bool, Tuple[bool, bool]], [True, False], 'name', TrueFalseBoth),
+    (Union[str, int, List[str], List[int]], [3, 5, -2], 'name', QMultiStrIntLineEdit),
+    (Union[str, int, Iterable[str], Iterable[int]], ['a', 'b', 'c'], 'name', QMultiStrIntLineEdit)
 
 ])
 def test_param_to_widget_nonnative_types(qtbot, param_type, default, name, expected_widget):
@@ -1124,14 +988,14 @@ def test_param_to_widget_nonnative_types(qtbot, param_type, default, name, expec
 
 
 @pytest.mark.parametrize('param_type,name,expected_widget,expected_widget_pipeline', [
-    (typing.Union[str, typing.List[str]], 'samples', TableColumnGroupPicker, QMultiLineEdit),
-    (typing.Iterable[str], 'sample_grouping', TableColumnGroupPicker, QMultiLineEdit),
-    (typing.Union[str, typing.List[str]], 'sample_names', TableColumnPicker, QMultiLineEdit),
-    (typing.List[str], 'sample1', TableColumnPicker, QMultiLineEdit),
-    (typing.List[str], 'sample2', TableColumnPicker, QMultiLineEdit),
-    (typing.List[str], 'columns', TableColumnPicker, QMultiLineEdit),
-    (str, 'by', TableSingleColumnPicker, QtWidgets.QLineEdit),
-    (str, 'column', TableSingleColumnPicker, QtWidgets.QLineEdit),
+    (param_typing.GroupedColumns, 'samples', TableColumnGroupPicker, TwoLayerMultiLineEdit),
+    (param_typing.GroupedColumns, 'sample_grouping', TableColumnGroupPicker, TwoLayerMultiLineEdit),
+    (param_typing.ColumnNames, 'sample_names', TableColumnPicker, QMultiLineEdit),
+    (param_typing.ColumnNames, 'sample1', TableColumnPicker, QMultiLineEdit),
+    (param_typing.ColumnNames, 'sample2', TableColumnPicker, QMultiLineEdit),
+    (param_typing.ColumnNames, 'columns', TableColumnPicker, QMultiLineEdit),
+    (param_typing.ColumnName, 'by', TableSingleColumnPicker, QtWidgets.QLineEdit),
+    (param_typing.ColumnName, 'column', TableSingleColumnPicker, QtWidgets.QLineEdit),
 
 ])
 def test_param_to_widget_pipeline_mode_types(qtbot, param_type, name, expected_widget, expected_widget_pipeline):
@@ -1140,13 +1004,17 @@ def test_param_to_widget_pipeline_mode_types(qtbot, param_type, name, expected_w
 
 
 @pytest.mark.parametrize('param_type,default,literal_default,expected_sub_widget', [
-    (typing.Union[Literal['all'], str], 'text', 'all', QtWidgets.QLineEdit),
-    (typing.Union[Literal['any'], typing.Union[str, None]], None, 'any', OptionalLineEdit),
-    (typing.Union[Literal['any', 'none'], typing.Union[int, typing.List[int]]], [15, 16], 'any', QMultiSpinBox),
+    (Union[Literal['all'], str], 'text', 'all', QtWidgets.QLineEdit),
+    (Union[Literal['any'], str, None], None, 'any', ComboBoxOrOtherWidget),
+    (Union[Literal['any'], str, int], 5, 'any', StrIntLineEdit),
+    (Union[Literal['any', 'none'], Union[int, List[int]]], [15, 16], 'any', QMultiSpinBox),
 
 ])
 def test_param_to_widget_with_literals(qtbot, param_type, default, literal_default, expected_sub_widget):
-    expected_widget = ComboBoxOrOtherWidget
+    if expected_sub_widget == ComboBoxOrOtherWidget:
+        expected_widget = OptionalWidget
+    else:
+        expected_widget = ComboBoxOrOtherWidget
     _run_param_to_widget(qtbot, param_type, default, 'name', expected_widget)
     _run_param_to_widget(qtbot, param_type, literal_default, 'name', expected_widget)
 
